@@ -22,7 +22,11 @@ class Settings
         char *_headerLeftFilename;
         char *_headerRightFilename;
         char *_headerMiddleFilename;
+        char *_headerLeftSelectedFilename;
+        char *_headerRightSelectedFilename;
+        char *_headerMiddleSelectedFilename;
         char *_borderColor;
+        char *_borderActiveColor;
 
         int _borderWidth;
         int _textLeftMargin;
@@ -55,7 +59,11 @@ class Settings
         const char* headerLeftFilename() { return _headerLeftFilename; }
         const char* headerRightFilename() { return _headerRightFilename; }
         const char* headerMiddleFilename() { return _headerMiddleFilename; }
+        const char* headerLeftSelectedFilename() { return _headerLeftSelectedFilename; }
+        const char* headerRightSelectedFilename() { return _headerRightSelectedFilename; }
+        const char* headerMiddleSelectedFilename() { return _headerMiddleSelectedFilename; }
         char* borderColor() { return _borderColor; }
+        char* borderActiveColor() { return _borderActiveColor; }
 
         int borderWidth() { return _borderWidth; }
         int textLeftMargin() { return _textLeftMargin; }
