@@ -163,7 +163,7 @@ TeleWindow::TeleWindow(Display *dpy)
     _picture = XRenderCreatePicture(_dpy, _win, _xrenderFormat, CPSubwindowMode, &pa);
 
     // Xft Draw object
-    _xftDraw = XftDrawCreate(_dpy, _bufferPix, visual, colormap);
+    recreateXftDraw();
 
 
     _shown = false;
@@ -229,6 +229,8 @@ void TeleWindow::show()
 {
     _shown = true;
 
+    updateThumbnailsList();
+
     Window activeWindow = XTools::activeWindow();
 
     _activeThumbnail = 0;
@@ -468,7 +470,17 @@ void TeleWindow::eventLoop()
                 {
                     if ((*i)->clientWindow() == event.xany.window)
                     {
-                        (*i)->onClientEvent(&event);
+                        if (event.type == DestroyNotify)
+                        {
+                            (*i)->setClientDestroyed(true);
+                            removeThumbnail(*i);
+                            delete *i;
+                            // markThumbnailsListDirty();
+                            layoutThumbnails();
+                        }
+                        else
+                            (*i)->onClientEvent(&event);
+
                         found = true;
                         break;
                     }
@@ -493,7 +505,8 @@ void TeleWindow::onRootEvent(XEvent *event)
     if (event->type == KeyRelease && event->xkey.keycode == _hotKeyCode)
         onHotKeyRelease();
 //    else if (event->type == MapNotify)
-//        updateThumbnailsList();
+//    {
+//    }
     else if (event->type == PropertyNotify)
     {
 //        char *name = XGetAtomName(_dpy, event->xproperty.atom);
@@ -655,7 +668,7 @@ void TeleWindow::paint()
             (const FcChar8*)(*i)->title(),
             strlen((*i)->title())
         );
-        
+
         XDestroyRegion(clip);
     }
 
@@ -893,6 +906,8 @@ void TeleWindow::setNewSize(int width, int height)
 
     reloadBackground();
 
+    recreateXftDraw();
+
     layoutThumbnails();
 }
 
@@ -1042,6 +1057,21 @@ void TeleWindow::recreateBufferPixmap()
     _bufferPicture = XRenderCreatePicture(_dpy, _bufferPix, _xrenderFormat, 0, 0);
 }
 
+void TeleWindow::recreateXftDraw()
+{
+    if (_xftDraw)
+    {
+        XftDrawDestroy(_xftDraw);
+        _xftDraw = 0;
+    }
+
+    int scr = DefaultScreen(_dpy);
+    Visual *visual = DefaultVisual(_dpy, scr);
+    Colormap colormap = DefaultColormap(_dpy, scr);
+
+    _xftDraw = XftDrawCreate(_dpy, _bufferPix, visual, colormap);
+}
+
 
 bool TeleWindow::loadARGBImage(
     const char *filename,
