@@ -22,7 +22,6 @@ class Thumbnail
         Damage _damage;
 
         Picture _clientPict;
-        Picture _pict;
 
         int _depth;
         Pixmap _cachePixmap;
@@ -55,6 +54,8 @@ class Thumbnail
 //        Window window();
         Window clientWindow();
 
+        void setClientDestroyed(bool clientDestroyed) { _clientDestroyed = clientDestroyed; }
+
         char* title();
 
         void setGeometry(int x, int y, int w, int h);
