@@ -28,25 +28,27 @@ Atom XTools::_NET_ACTIVE_WINDOW;
 Atom XTools::_NET_SHOWING_DESKTOP;
 Atom XTools::_NET_CLOSE_WINDOW;
 Atom XTools::WM_STATE;
+Atom XTools::WM_NAME;
 
 
-#define INIT_ATOM(dpy, ATOMNAME)		ATOMNAME = XInternAtom((dpy), #ATOMNAME, 0L)
+#define INIT_ATOM(dpy, ATOMNAME)        ATOMNAME = XInternAtom((dpy), #ATOMNAME, 0L)
 
 void XTools::init(Display *dpy)
 {
-	_dpy = dpy;
+    _dpy = dpy;
 
-	INIT_ATOM(dpy, _NET_CLIENT_LIST);
-	INIT_ATOM(dpy, _NET_WM_WINDOW_TYPE);
-	INIT_ATOM(dpy, _NET_WM_WINDOW_TYPE_NORMAL);
-	INIT_ATOM(dpy, _NET_WM_NAME);
-	INIT_ATOM(dpy, _NET_WM_STATE);
-	INIT_ATOM(dpy, _NET_WM_STATE_FULLSCREEN);
-	INIT_ATOM(dpy, _NET_WM_STATE_HIDDEN);
-	INIT_ATOM(dpy, _NET_ACTIVE_WINDOW);
+    INIT_ATOM(dpy, _NET_CLIENT_LIST);
+    INIT_ATOM(dpy, _NET_WM_WINDOW_TYPE);
+    INIT_ATOM(dpy, _NET_WM_WINDOW_TYPE_NORMAL);
+    INIT_ATOM(dpy, _NET_WM_NAME);
+    INIT_ATOM(dpy, _NET_WM_STATE);
+    INIT_ATOM(dpy, _NET_WM_STATE_FULLSCREEN);
+    INIT_ATOM(dpy, _NET_WM_STATE_HIDDEN);
+    INIT_ATOM(dpy, _NET_ACTIVE_WINDOW);
     INIT_ATOM(dpy, _NET_SHOWING_DESKTOP);
     INIT_ATOM(dpy, _NET_CLOSE_WINDOW);
     INIT_ATOM(dpy, WM_STATE);
+    INIT_ATOM(dpy, WM_NAME);
 
     checkDamageExtension();
 
@@ -55,59 +57,62 @@ void XTools::init(Display *dpy)
 
 LinkedList<Window> XTools::windowList(Window rootWindow)
 {
-	LinkedList<Window> list;
+    LinkedList<Window> list;
 
-	Atom real_type;
-	int real_format;
-	unsigned long items_read, items_left;
-	Window *windows;
-	if (XGetWindowProperty(_dpy, rootWindow, _NET_CLIENT_LIST, 0L, 8192L, False,
-		XA_WINDOW, &real_type, &real_format, &items_read, &items_left, (unsigned char**)&windows)
-		!= Success)
-	{
-		return list;
-	}
-	else
-	{
-		for (unsigned int i = 0; i < items_read; i++)
-		{
-			unsigned long items_read, items_left;
-			Atom real_type;
-			int real_format;
-			Atom *windowType;
+    Atom real_type;
+    int real_format;
+    unsigned long items_read, items_left;
+    Window *windows;
+    if (XGetWindowProperty(_dpy, rootWindow, _NET_CLIENT_LIST, 0L, 8192L, False,
+        XA_WINDOW, &real_type, &real_format, &items_read, &items_left, (unsigned char**)&windows)
+        != Success)
+    {
+        return list;
+    }
+    else
+    {
+        for (unsigned int i = 0; i < items_read; i++)
+        {
+            unsigned long items_read, items_left;
+            Atom real_type;
+            int real_format;
+            Atom *windowType;
 
-			if (XGetWindowProperty(_dpy, windows[i], _NET_WM_WINDOW_TYPE, 0L, 1L, False,
-				XA_ATOM, &real_type, &real_format, &items_read, &items_left,
-				(unsigned char**)&windowType) != Success)
-			{
-				continue;
-			}
-			else
-			{
-				bool ok = (items_read > 0 && *windowType == _NET_WM_WINDOW_TYPE_NORMAL);
+            if (XGetWindowProperty(_dpy, windows[i], _NET_WM_WINDOW_TYPE, 0L, 1L, False,
+                XA_ATOM, &real_type, &real_format, &items_read, &items_left,
+                (unsigned char**)&windowType) != Success)
+            {
+                continue;
+            }
+            else
+            {
+                //bool ok = (items_read > 0 && *windowType == _NET_WM_WINDOW_TYPE_NORMAL);
+                bool ok = true;
+                if (items_read > 0 && *windowType != _NET_WM_WINDOW_TYPE_NORMAL)
+                    ok = false;
 
-				XFree((unsigned char*)windowType);
+                XFree((unsigned char*)windowType);
 
-				if (! ok)
-				{
-					continue;
-				}
-			}
+                if (! ok)
+                {
+                    continue;
+                }
+            }
 
-			list.append(windows[i]);
-		}
+            list.append(windows[i]);
+        }
 
-		XFree((unsigned char*)windows);
+        XFree((unsigned char*)windows);
 
-		return list;
-	}
+        return list;
+    }
 }
 
 
 char* XTools::windowTitle_alloc(Window window)
 {
-	XTextProperty wmName;
-	XGetTextProperty(_dpy, window, &wmName, _NET_WM_NAME);
+    XTextProperty wmName;
+    XGetTextProperty(_dpy, window, &wmName, _NET_WM_NAME);
     if (wmName.value)
     {
         char *ret = strdup((char*)wmName.value);
@@ -116,9 +121,19 @@ char* XTools::windowTitle_alloc(Window window)
     }
     else
     {
-        char *ret = (char*)malloc(1);
-        *ret = '\0';
-        return ret;
+        XGetTextProperty(_dpy, window, &wmName, WM_NAME);
+        if (wmName.value)
+        {
+            char *ret = strdup((char*)wmName.value);
+            XFree(wmName.value);
+            return ret;
+        }
+        else
+        {
+            char *ret = (char*)malloc(1);
+            *ret = '\0';
+            return ret;
+        }
     }
 }
 
